package com.canon.ui.tools.fontCheck;

import java.awt.Font;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.util.ArrayList;

public class FontTestDataCreator {


	public ArrayList<byte[]> asciiArray = new ArrayList<byte[]>();
	public ArrayList<byte[]> gb180302byteCodeList = new ArrayList<byte[]>();
	public ArrayList<byte[]> gb180304byteCodeList = new ArrayList<byte[]>();
	
	private boolean logmode=true;
	
	public void setLogmode(boolean b) {logmode = b;}
	
	private void println(String str) {
		if(logmode) {
			System.out.println(str);
		}
	}
	
	public void createAsciiCodeList() {
		/*ASCII 0x20-0x7E*/
		asciiArray.clear();

		byte byteStr[] = new byte[1];
		for(byte i=0x20;i<=0x7E;i++) {
			byteStr[0] = i;
			updateArrayListWithCheck(asciiArray,byteStr);


		}
	}

	private int getStringCodeAsInt(byte[] b) {
		int ret =  ByteBuffer.wrap(b).getInt();
		return ret;
	}
	

	public ArrayList<byte[]> getStringCodeGB18030AsByteArrayList() {
		ArrayList<byte[]> ret = new ArrayList<byte[]>();
		
		asciiArray.stream().forEach( a -> ret.add(a));
		gb180302byteCodeList.stream().forEach( a -> ret.add(a));
		gb180304byteCodeList.stream().forEach( a -> ret.add(a));
		
		ret.stream().sorted();
		
		return ret;
		
	}
	
	public ArrayList<Integer> getStringCodeGB18030AsIntegerArrayList() {
		ArrayList<Integer> ret = new ArrayList<Integer>();
		
		asciiArray.stream().forEach( a -> ret.add(getStringCodeAsInt(a)));
		gb180302byteCodeList.stream().forEach( a -> ret.add(getStringCodeAsInt(a)));
		gb180304byteCodeList.stream().forEach( a -> ret.add(getStringCodeAsInt(a)));
		ret.stream().sorted();
		
		return ret;
		
	}
	
	private void updateArrayListWithCheck(ArrayList<byte[]> array,byte[] ba) {
		Font font = new Font(Font.SERIF, Font.PLAIN,24);
		try {
			String str = new String(ba,"GB18030");
			char c = str.charAt(0);
			if(font.canDisplay(c)) {
				array.add(ba);
			} else {
				println("GB18030:"+javax.xml.bind.DatatypeConverter.printHexBinary(ba) + " doesn't have glyph");
			}
			
		} catch (UnsupportedEncodingException e) {
			// TODO 自動生成された catch ブロック
			//e.printStackTrace();
			println("GB18030:"+javax.xml.bind.DatatypeConverter.printHexBinary(ba) + "can not convert to Unicode");
		}
	}
	
	public void createGB18030StringCode() {

		createAsciiCodeList();
	
		/*２バイト文字*/
		{
			byte byte2Str[] = new byte[2];

			for(int b1 =  0x81 ; b1 <= 0xFE;b1++) {
				byte2Str[0] = (byte)b1;
				for(int b2 = 0x40 ; b2 <= 0x7E;b2++) {

					byte2Str[1] = (byte)b2;
					
					updateArrayListWithCheck(gb180302byteCodeList,byte2Str);
					
				}
				
				for(int b2 = 0x80 ; b2 <= 0xFE;b2++) {

					byte2Str[1] = (byte)b2;
					
					updateArrayListWithCheck(gb180302byteCodeList,byte2Str);
					
				}
				

			}

		}

		/*４バイト文字*/
		{
			byte byte4Str[] = new byte[4];

			for(int b1 =  0x81 ; b1 <= 0xFE;b1++) {
				byte4Str[0] = (byte)b1;
				for(int b2 =  0x30 ; b2 <= 0x39;b2++) {

					byte4Str[1] = (byte)b2;

					for(int b3 =  0x81 ; b3 <= 0xFE;b3++) {
						byte4Str[2] = (byte)b3;
						for(int b4 =  0x30 ; b4 <= 0x39;b4++) {

							byte4Str[3] = (byte)b4;
							updateArrayListWithCheck(gb180304byteCodeList,byte4Str);
						
						}
					}

				}

			}

		}

	}

//	public static void main(String[] args) {
//		// TODO 自動生成されたメソッド・スタブ
//		FontTestDataCreator ftdc = new FontTestDataCreator();
//		
//		ftdc.setLogmode(false);
//		ftdc.createGB18030StringCode();
//		
//		System.out.println("GB18030 1byte string num:" + ftdc.asciiArray.size());
//		System.out.println("GB18030 2byte string num:" + ftdc.gb180302byteCodeList.size());
//		System.out.println("GB18030 4byte string num:" + ftdc.gb180304byteCodeList.size());
//		
//
//	}

}
